@@ -88,11 +88,17 @@ class Filter(DataClassJsonMixin):
   id: str
   name: str
   description: str
-  user_secret_id: str
   prompt: str
   
   ddim_steps: int
   scale: float 
   strength: float
   
+  user_secret_id: typing.Optional[str] = None
   creation_time: datetime = datetime.now()
+
+@dataclass
+class AppFilters(DataClassJsonMixin):
+  app_id: str
+  filters: list[Filter]
+  
